%define name            zope
%define majorversion    2.7
%define minorversion    1
%define rel             0
%define version         %{majorversion}.%{minorversion}
%define packagename     Zope-%{version}
%define buildroot       %{_tmppath}/%{packagename}-root

%define zopehome        /usr/lib/%{name}
%define softwarehome    %{zopehome}/lib/python
%define instancehome    /var/zope
%define clienthome      /var/zope/data
%define statehome       /var/run/zope
%define loghome         /var/log/zope
%define configfile      /etc/zope.conf
%define zopectl         /usr/bin/zopectl
%define runzope         /usr/bin/runzope
%define zopeuser        zope

%define __python        /usr/bin/python2.3

Summary:            Zope, the open source web application server
Name:               %{name}
Version:            %{version}
Release:            %{rel}ied00
License:            Zope Public License (ZPL)
Group:              Applications/Zope
BuildRoot:          %{buildroot}
Vendor:             Zope Corporation and Contributors <zope@zope.org>
URL:                http://www.zope.org
Requires:           /usr/sbin/useradd /sbin/chkconfig /bin/sh
Source:             http://zope.org/Products/Zope/%{version}/%{packagename}.tgz
Source1:            skel.tgz

Patch0:             Zope-2.6.2-PRC-timezone.patch
Patch1:             Zope-2.7.0-managemain-scrollbar.patch
Patch2:             Zope-2.6.2-ZPT-charset.patch
Patch3:             Zope-2.7.0-initrc.patch
Patch4:             Zope-2.7.0-STX-chinese.patch
Patch5:             Zope-2.7.0-builtins.patch
Patch6:             Zope-2.7.0-external-editor.patch
Patch7:             Zope-2.7.0-dbtest-maxwidth.patch

# The autorequire script sticks "/usr/local/bin/python"
# into the required list due to script shebangs in Zope.  Turn off auto
# requires/provides for this reason and roll our own Requires/Provides lists
#AutoReqProv: no
#
# Will fix shebangs later
#
#Requires: python2.3 >= 2.3 , ld-linux.so.2, libc.so.6
Requires:           python2.3 >= 2.3
BuildRequires:      python2.3 >= 2.3

#----------------------------------------------------------------------
%description

Zope is an application server framework that enables developers to quickly
build web applications such as intranets, portals, and content management
systems.

#----------------------------------------------------------------------
%prep

%setup -q -n %{packagename}-%{rel}

#
# Zope patches
#
pushd lib/python

%patch0 -p0 -b .timezone
%patch1 -p0 -b .scrollbar
%patch2 -p0 -b .charset
%patch4 -p0 -b .stxcn
%patch5 -p0 -b .builtins
%patch6 -p0 -b .exteditor
%patch7 -p0 -b .maxwidth

popd

#
# Extract skel and apply patches
#
%{__mkdir} extra
%setup -q -a 1 -T -D -n %{packagename}-%{rel}/extra

cd skel
rm etc/logrotate.d/zope.in.~1.1.1.1.~
%patch3 -p0

#
# reset context
#
%setup -T -D -n %{packagename}-%{rel}

#
# Fix script shebangs
#
pushd utilities
PATTERN='^#! *((/usr)?/bin/env +)?(/usr/(local/)?bin/)?python.*$'

%{__grep} -rlIE "$PATTERN" . | while read script ; do
  %{__sed} -n -r -e "s:$PATTERN:#!\\1%{__python}:" -e "w $script.fixed" $script
  %{__cp} $script.fixed $script
  %{__rm} $script.fixed
done

for script in *.py ; do
   if [ -z "`head -1 $script | grep '^#!'`" ] ; then
      %{__mv} $script $script.tmp
      echo -e "#!%{__python}\n" > $script
      cat $script.tmp >> $script
      %{__rm} $script.tmp
   fi
done
%{__grep} -l '^#!' *.py | xargs %{__chmod} 755

popd

#----------------------------------------------------------------------
%build

%{__mkdir} build
pushd build
../configure \
   --with-python="%{__python}" \
   --prefix="%{buildroot}%{zopehome}" \
   --no-compile
%{__make} build
popd

#----------------------------------------------------------------------
%install
[ "$RPM_BUILD_ROOT" != "/" ] && %{__rm} -rf $RPM_BUILD_ROOT

pushd build
%{__make} install
popd

# process the skel directory into the buildroot
%{__python} "utilities/copyzopeskel.py" \
         --sourcedir="extra/skel" \
         --targetdir="%{buildroot}" \
         --replace="INSTANCE_HOME:%{instancehome}" \
         --replace="CLIENT_HOME:%{clienthome}" \
         --replace="STATE_DIR:%{statehome}" \
         --replace="LOG_DIR:%{loghome}" \
         --replace="SOFTWARE_HOME:%{softwarehome}" \
         --replace="ZOPE_HOME:%{zopehome}" \
         --replace="CONFIG_FILE:%{configfile}" \
         --replace="PYTHON:%{__python}" \
         --replace="ZOPECTL:%{zopectl}" \
         --replace="RUNZOPE:%{runzope}" \

%{__cp} -a lib/python/version.txt %{buildroot}%{softwarehome}

#----------------------------------------------------------------------
%pre

# add a Zope user if one doesn't already exist
user=`cut -f1 -d: /etc/passwd|grep "^%{zopeuser}$"`
group=`cut -f1 -d: /etc/group|grep "^%{zopeuser}$"`
if [ -z "$group" ]; then
    /usr/sbin/groupadd -g 65 -o -r zope
fi
if [ -z "$user" ]; then
    /usr/sbin/useradd -M -n -g %{zopeuser} -o -r -s /sbin/nologin \
       -d "%{instancehome}" -c "Zope service user" -u 65 %{zopeuser}
fi

#----------------------------------------------------------------------
%post

# byte-compile installed Python files
pushd "%{zopehome}" > /dev/null 2>&1
%{__python} "%{zopehome}/bin/compilezpy.py" > /dev/null 2>&1 || :
popd > /dev/null 2>&1

/sbin/chkconfig --add zope

# write a 10 digit random default admin password into acl_users
if [ "$1" = 1 ]; then
   passwd=`head -c4 /dev/urandom | od -tu4 -N4 | sed -ne '1s/.* //p'`
   %{zopectl} adduser admin $passwd

   # inform the user of the default username/password combo and port
   echo
   echo A Zope instance has been installed.  Run it via
   echo \"/etc/rc.d/init.d/zope start\".  Log in via a browser on port 9080.
   echo
   echo Zope has default administrative username/password combination.  The
   echo administrative username is \"admin\" and the password is \"$passwd\".
   echo Please remember this so you are able to log in for the first time.
   echo
fi

#----------------------------------------------------------------------
%preun

if [ "$1" = 0 ] ; then
   if [ -f "/etc/rc.d/init.d/zope" ]; then
      /etc/rc.d/init.d/zope stop > /dev/null 2>&1
   fi
   /sbin/chkconfig --del zope
   find "%{zopehome}" -name "*.py[co]"| xargs %{__rm} -f
fi

#----------------------------------------------------------------------
%postun

if [ "$1" = 0 ] ; then
   /usr/sbin/userdel zope > /dev/null 2>&1 || :
   /usr/sbin/groupdel zope > /dev/null 2>&1 || :
fi

#----------------------------------------------------------------------
%clean
[ "$RPM_BUILD_ROOT" != "/" ] && %{__rm} -rf $RPM_BUILD_ROOT

#----------------------------------------------------------------------
%files
%defattr(-,root,root)
%dir %{zopehome}
%{zopehome}/bin
%{zopehome}/doc
%{zopehome}/import
%{zopehome}/lib
%{zopehome}/skel
%config /etc/zope.conf
/etc/logrotate.d/zope
/etc/rc.d/init.d/zope
/usr/bin/runzope
/usr/bin/zopectl
%attr(-, %{zopeuser}, %{zopeuser}) /var/zope
%attr(-, %{zopeuser}, %{zopeuser}) %dir /var/log/zope
%attr(-, %{zopeuser}, %{zopeuser}) %dir /var/run/zope
/var/run/zope/README.txt
/var/log/zope/README.txt

#----------------------------------------------------------------------
%changelog
* Wed Jun 23 2004 Wei He <hewei@ied.org.cn> 2.7.1-0ied00
- updated to Zope-2.7.1
- spec file cleanups

* Tue Apr 20 2004 Wei He <hewei@ied.org.cn> 2.7.0-1ied03
- Maximized the width of query textarea in a
  SQL connection's 'Test' tab

* Mon Feb 23 2004 Wei He <hewei@ied.org.cn> 2.7.0-1ied02
- Fixed script shebangs instead of turning off AutoReqProv

* Fri Feb 20 2004 Wei He <hewei@ied.org.cn> 2.7.0-1ied01
- Added patches to be forward compatible with ExteralEditor

* Fri Feb 13 2004 Wei He <hewei@ied.org.cn> 2.7.0-0ied00
- updated to Zope-2.7.0

* Thu Feb 5 2004 Wei He <hewei@ied.org.cn> 2.7.0-rc2ied00
- base dir changed from /usr/lib/zope2.7 to /usr/lib/zope
- now requires seperate python2.3 packages

* Sat Jan 17 2004 Wei He <hewei@ied.org.cn> 2.7.0-b3ied03
- Will not try generating zope password while upgrading
- Added 'status' command to zope rc script
- Property tab now respects management_page_charset
- Zope version now displays in the Control_Panel page correctly

* Fri Jan 9  2004 Wei He <hewei@ied.org.cn>
- Update for Zope 2.7b3
- Fixed the dirty buildroot bug
- Now support PRC timezone. CST is now considered as China Standard Time
- Scroll bar of the textarea in manage_main page is no longer hidden
- Specifying charset in the content_type property of a ZPT now works
- Patched StructuredText to support ASCII >= 128

* Tue Jul 22 2003 Chris McDonough <chrism@zope.com>
- Update for Zope 2.7b1+
- run ./configure from build subdirectory instead of in Zope source root
- install an instance home with a  default username and random password
- byte-compile files in postinstall instead of during install
- explicitly name directories in "files" section rather than writing
  a manifest from the build
- dont use auto Requires/Provides support
- install an rc script
- install logrotate.d script
- known issues: zopesock socket file is written as root, need to
  write rpm-specific doc files to /usr/share/doc/Zope-X.X.X

* Fri Oct 11 2002 Chris McDonough <chrism@zope.com>
- Initial release
